#ifndef DEFINE_ISLIB_SYSTEM_ERROR_HPP

#define DEFINE_ISLIB_SYSTEM_ERROR_HPP

//
// Inclusion of standard header file
//
#include <stdexcept>
#include <string>

namespace islib
  {
    //
    // Definition of class
    //
    class system_error:
      public std::runtime_error
      {
      public:
        //
        // Definition of type
        //
        typedef system_error this_type;
        typedef std::string string_type;

        //
        // Declaration of constructor
        //
        explicit system_error ( string_type const & );

        //
        // Declaration of destructor
        //
        virtual ~system_error () throw ();
      };
  }

#endif // DEFINE_ISLIB_SYSTEM_ERROR_HPP

//
// End of file
//
